/* Power of Divisors
 *
 * Special case n = 1. Any other value will have exponent at most log2(10^18),
 * which is less than 64. Try every possible exponent, take an integer n-th
 * root, and count the divisors of the found root. Counting divisors can be done
 * by precomputing all primes < (10^18)^(1/4).
 */
#include <cmath>
#include <cstdint>
#include <iostream>
#include <vector>

std::vector<int64_t> primes;

void genPrimes() {
    constexpr int64_t CAP = 32000;
    static_assert(CAP * CAP * CAP * CAP > 1e18);

    std::vector<bool> sieve(CAP, false);
    for (int64_t d = 2; d < CAP; ++d) {
        if (!sieve[d]) {
            primes.push_back(d);
            for (int64_t j = d * d; j < CAP; j += d) {
                sieve[j] = true;
            }
        }
    }
}

// count number of divisors
int64_t sigma0(int64_t x) {
    int64_t ans = 1;
    for (int64_t p : primes) {
        if (p > x) break;
        int64_t e = 0;
        while (x % p == 0) {
            ++e;
            x /= p;
        }

        ans *= (e + 1);
    }

    if (x > 1) ans *= 2;

    return ans;
}

constexpr int64_t INF = std::numeric_limits<int64_t>::max();
int64_t safeMul(int64_t a, int64_t b) {
    if (a == INF || b == INF || a > INF / b) {
        return INF;
    }

    return a * b;
}

int64_t safePow(int64_t base, int64_t exp) {
    if (exp == 0) return 1;
    if (exp % 2 == 1) return safeMul(base, safePow(base, exp - 1));

    return safePow(safeMul(base, base), exp / 2);
}

int main() {
    genPrimes();

    int64_t x;
    std::cin >> x;

    if (x == 1) {
        std::cout << 1 << '\n';
        return 0;
    }

    int64_t cur = 2;
    for (auto exp = 64; exp > 2; --exp) {
        while (safePow(cur, exp) < x) {
            ++cur;
        }

        if (safePow(cur, exp) == x && sigma0(cur) == exp) {
            std::cout << cur << '\n';
            return 0;
        }
    }

    // special case square of prime
    {
        int64_t r = std::sqrt(x);
        while (r * r < x) {
            ++r;
        }

        if (r * r == x && sigma0(r) == 2) {
            std::cout << r << '\n';
            return 0;
        }
    }

    std::cout << -1 << '\n';
    return 0;
}
